import numpy as np

def make_blob(color = (0, 162, 232),transparency = (200, 191, 231)):

    return np.array(
        [[transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [255, 255, 255],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        [63, 72, 204],
        [63, 72, 204],
        [63, 72, 204],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        [255, 255, 255],
        [255, 255, 255],
        [255, 255, 255],
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        color,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency],
        [transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency,
        transparency]]
    ).swapaxes(0,1)