import numpy as np
def make_arrow(color = (63,72,204),color2 = None,transparency = (200,191,231)):

    if color2 is None:
        color2 = color

    return np.flip(np.array(
        [[transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         color2,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency],
         [transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency,
         transparency]]
),axis = 0)
